'''
Triton Server Support for building model repository.
----
Author: Quang-Minh Doan (Vietnam)
Github: https://github.com/Ming-doan/trsp
----
MIT License

Copyright (c) 2024 Quang-Minh Doan

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
'''


def get_pip_install(requirements: list[str]):
    '''
    Get pip install command for Dockerfile.
    '''
    return '\n'.join(f'RUN pip install {requirement}' for requirement in requirements)


def get_docker_template(requirements: list[str]): return f'''# Dockerfile for Deploy Triton Server.
# Auto generated by `trsp` module. Developed by Ming-doan.
# ------------------------------

# Use the official image as a parent image
FROM nvcr.io/nvidia/tritonserver:23.12-py3

# Install dependencies
{get_pip_install(requirements)}

# Set volume
VOLUME /models

# Expose the port
EXPOSE 8000
EXPOSE 8001
EXPOSE 8002

# Run the server
CMD ["tritonserver", "--model-repository=/models"]

'''
